@@ -11,9 +11,17 @@ from emannotationschemas.schemas.functional_coregistration import (
     FunctionalUnitCoregistrationExtended,
 )
 from emannotationschemas.schemas.postsynaptic_compartment import PostsynapticCompartment
-from emannotationschemas.schemas.base import FlatSegmentationReferenceSinglePoint
-from emannotationschemas.schemas.cell_type_local import CellTypeLocal
-from emannotationschemas.schemas.bound_text_tag import BoundTagAnnotation
+from emannotationschemas.schemas.base import (
+    FlatSegmentationReferenceSinglePoint,
+    ReferenceBoundSpatialPoint,
+)
+from emannotationschemas.schemas.cell_type_local import CellTypeLocal, CellTypeReference
+from emannotationschemas.schemas.bound_text_tag import (
+    BoundTagAnnotation,
+    Bound2TagAnnotation,
+    BoundTagAnnotationUser,
+    Bound2TagAnnotationUser,
+)
 from emannotationschemas.schemas.glia_contact import GliaContact
 from emannotationschemas.schemas.contact import Contact
 from emannotationschemas.schemas.extended_classical_cell_type import (
@@ -35,7 +43,7 @@ from emannotationschemas.schemas.neuropil import FlyNeuropil
 from emannotationschemas.errors import UnknownAnnotationTypeException
 from emannotationschemas.flatten import create_flattened_schema
 
-__version__ = "3.5.3"
+__version__ = "3.8.0"
 
 type_mapping = {
     "synapse": SynapseSchema,
@@ -49,8 +57,12 @@ type_mapping = {
     "microns_func_unit_coreg": FunctionalUnitCoregistration,
     "microns_func_unit_ext_coreg": FunctionalUnitCoregistrationExtended,
     "cell_type_local": CellTypeLocal,
+    "cell_type_reference": CellTypeReference,
     "nucleus_detection": NucleusDetection,
     "bound_tag": BoundTagAnnotation,
+    "bound_2tag": Bound2TagAnnotation,
+    "bound_tag_user": BoundTagAnnotationUser,
+    "bound_2tag_user": Bound2TagAnnotationUser,
     "extended_classical_cell_type": ExtendedClassicalCellType,
     "plastic_synapse": PlasticSynapse,
     "glia_contact": GliaContact,
@@ -62,6 +74,7 @@ type_mapping = {
     "compartment_proofread_status": CompartmentProofreadStatus,
     "proofreading_boolstatus_user": ProofreadingBoolStatusUser,
     "fly_neuropil": FlyNeuropil,
+    "reference_point": ReferenceBoundSpatialPoint,
 }
 
 
